/*
 * Copyright (c) 2004 Atmark Techno, Inc.  All Rights Reserved.
 */

#include <target/buffer.h>
#include <target/crc.h>
#include <target/io.h>
#include <ep93xx/ioregs.h>
#include "flash.h"
#include "frob.h"
#include "linux.h"
#include "memmap.h"
#include "eth.h"
#include "board.h"

/* timeout for auto-boot, in seconds */
#define BOOT_TIMEOUT 5

static const command_t *commands[] = {
	&help_command,
	&boot_command,
	&clearenv_command,
	&download_command,
	&flash_erase_command,
	&frob_command,
	&jump_command,
	&linux_command,
	&medium_command,
	&memmap_command,
	&flash_program_command,
	&setenv_command,
	&unzip_command,
	&upload_command,
	&version_command,
	0
};

ABBR(boot_command, 'b')
ABBR(help_command, '?')
ABBR(frob_command, 'f')
ABBR(version_command, 'V')

static const abbrev_t *abbrevs[] = {
	&boot_command_abbrev,
	&help_command_abbrev,
	&frob_command_abbrev,
	&version_command_abbrev,
	0
};

static inline void maybe_start_linux(void)
{
#if defined STANDALONE
	/* always go to the command loop */
#else
	/* boot linux unless a key is pressed before the timeout elapses */
	hprintf("Press a key within %d seconds for console.\n", BOOT_TIMEOUT);
	IO_RTCMR = IO_RTCDR + BOOT_TIMEOUT;
	while (IO_SYSFLG1 & URXFE1) {
		if (IO_RTCMR <= IO_RTCDR) {
			/* start linux */
		}
	}
#endif
}

int hmain(void)
{
	command_list_t command_list = { commands, abbrevs, "hermit", 0 };

	//LED_GREEN_ON();
	//LED_RED_OFF();

	check_mode_jumper();
	disable_phy_module();
	maybe_start_linux();
#if !defined RELOCATE
	jumper_mode = 1;

#endif
	/* startup stuff: activate LED and print version string */
	(*version_command.func)(0, 0);

	if(get_board_id() != BOARD_ID_A210){
	  hprintf("warning: Not matched board type! This board is \"%s\".\n",
		  get_board_name(get_board_id()));	  
	}

	init_crc32();

	if(jumper_mode == 0){
	  //Linux-Boot
#if defined RELOCATE
	  (*boot_command.func)(0, 0);
#endif
	}

	LED_RED_OFF();
	do_command_loop(&command_list);
	for (;;);
}
