/*
 * Copyright (c) 2000 Blue Mug, Inc.  All Rights Reserved.
 */

#include <target/assert.h>
#include <target/crc.h>
#include <target/command.h>
#include <target/herrno.h>
#include <target/io.h>
#include <ep93xx/ioregs.h>

typedef enum medium_type {
	MEDIUM_SERIAL = 0,
} medium_t;
static medium_t current_medium;

#ifdef CONSOLE
#if CONSOLE == 1
#define	IO_UARTDR	IO_UART2DR
#define	IO_UARTFR	IO_UART2FR
#else
#define	IO_UARTDR	IO_UART1DR
#define	IO_UARTFR	IO_UART1FR
#endif
#endif


int hgetchar(void)
{
#ifdef CONSOLE
	while (IO_UARTFR & UARTFR_RXFE);
	return IO_UARTDR & 0xff;
#else
	return 0;
#endif
}

int hputchar(int c)
{
#ifdef CONSOLE
	while (IO_UARTFR & UARTFR_TXFF);
	IO_UARTDR = c;
#endif
	return 0;
}

int hgetblock(unsigned char *dst, int count)
{
	int remain = count;
	while (remain--)
		*dst++ = hgetchar();
	return count;
}

/*
 * This works for now, since medium only affects downstream data, not
 * replies from the target to the host.  Once we add upstream media
 * switching, we'll have to implement a delayed media switch that
 * allows the successful command return value to go out along the old
 * medium.
 */
static int medium_cmdfunc(int argc, char *argv[])
{
	medium_t medium;
	
	if (argc != 2)
		return -H_EUSAGE;
	++argv;
	if (!strcmp(*argv, "serial"))
		medium = MEDIUM_SERIAL;
	else
		return -H_EINVAL;
	if (medium == current_medium)
		return 0;
	IO_GPIO_PEDR = 0x1;	/* GREEN LED continuous on */
	current_medium = medium;
	return 0;
}

const command_t medium_command =
	{ "medium", "<medium name>",
	  "select communication medium",
	  &medium_cmdfunc };

